FactBinding

Struct FactBinding 

pub struct FactBinding { /* private fields */ }
Mapping from one gatekeep fact to one keepsake relation.

Implementations

Source

impl FactBinding

pub const fn new(fact: FactId, relation_id: RelationId) -> Self

Builds a binding that resolves in both decision and query mode.

pub const fn with_query_presence( fact: FactId, relation_id: RelationId, query_presence: QueryPresence, ) -> Self

Builds a binding with explicit query-mode behavior.

pub fn for_relation_spec<F, R>() -> Result<Self, FactBindingError>
where F: Fact, R: RelationSpec,

Binds a typed gatekeep fact to a typed keepsake relation.

Errors

Returns FactBindingError::Gatekeep if the fact marker exposes an invalid stable id.

pub fn resolve_relation<F, R>() -> Result<Self, FactBindingError>
where F: Fact, R: RelationSpec,

Binds a typed gatekeep fact to a typed keepsake relation that is resolved during query preparation.

Errors

Returns FactBindingError::Gatekeep if the fact marker exposes an invalid stable id.

pub fn defer_relation<F, R>() -> Result<Self, FactBindingError>
where F: Fact, R: RelationSpec,

Binds a typed gatekeep fact to a typed keepsake relation that is left unknown during query preparation for row-level lowering.

Errors

Returns FactBindingError::Gatekeep if the fact marker exposes an invalid stable id.

pub fn for_relation_spec_with_query_presence<F, R>( query_presence: QueryPresence, ) -> Result<Self, FactBindingError>
where F: Fact, R: RelationSpec,

Binds a typed gatekeep fact to a typed keepsake relation, with explicit query-mode behavior.

Errors

Returns FactBindingError::Gatekeep if the fact marker exposes an invalid stable id.

pub const fn fact(&self) -> &FactId

Returns the gatekeep fact id.

pub const fn relation_id(&self) -> RelationId

Returns the keepsake relation id.

pub const fn query_presence(&self) -> QueryPresence

Returns query-mode resolution behavior.