pub struct KeepsakeRelationTarget {
pub fact: FactId,
pub subject: SubjectRef,
pub relation_id: RelationId,
pub subject_slot: Option<SubjectSlot>,
}Expand description
Resolved keepsake target for a gatekeep fact binding.
Fields
fact: FactIdGatekeep fact that maps to this keepsake relation target.
subject: SubjectRefKeepsake subject used for relation lookups and lifecycle writes.
relation_id: RelationIdKeepsake relation definition id.
subject_slot: Option<SubjectSlot>Request-scoped subject slot used by this target, when any.
Implementations
Sourceimpl KeepsakeRelationTarget
impl KeepsakeRelationTarget
Sourcepub fn revoke_by_subject(
&self,
at: DateTime<Utc>,
context: CommandContext,
) -> RevokeBySubject
pub fn revoke_by_subject( &self, at: DateTime<Utc>, context: CommandContext, ) -> RevokeBySubject
Builds a keepsake revoke-by-subject command for this target.